@@ -2,7 +2,6 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) The Exim Maintainers 2025 */
 /* Copyright (c) University of Cambridge 1995 - 2009 */
 /* See the file NOTICE for conditions of use and distribution. */
 /* SPDX-License-Identifier: GPL-2.0-or-later */
@@ -26,7 +25,7 @@ extern auth_plaintext_options_block auth_plaintext_option_defaults;
 
 /* The entry points for the mechanism */
 
-extern void auth_plaintext_init(driver_instance *);
+extern void auth_plaintext_init(auth_instance *);
 extern int auth_plaintext_server(auth_instance *, uschar *);
 extern int auth_plaintext_client(auth_instance *, void *, int, uschar *, int);
 
